@@ -26,12 +26,34 @@
 class TestR : public BackendTest
 {
   Q_OBJECT
-
 private Q_SLOTS:
+    void testSimpleCommand();
+    void testMultilineCommand();
+    void testCommandQueue();
+
+    void testVariableDefinition();
+    void testMatrixDefinition();
+
+    void testCodeWithComments();
+    void testCommentExpression();
+    void testMultilineCommandWithComment();
+
+    void testInvalidSyntax();
+
+    void testCompletion();
+    void testHelpRequest();
+    void testSyntaxHelp();
+    void testInformationRequest();
+
+    void testSimplePlot();
+    void testComplexPlot();
+
     //tests variable model
     void testVariablesCreatingFromCode();
     void testVariableCleanupAfterRestart();
 
+    void testLoginLogout();
+    void testRestartWhileRunning();
 private:
     QString backendName() override;
 };
